@@ -137,7 +137,10 @@ extern template_app_info template_app_information;
 \
     int always_open_documentation;\
     int debug_mode;\
-    char *custom_load_path;
+    char *custom_load_path;\
+    char *force_ini;\
+    char *config_load_path;\
+    char *config_save_path;
 
 typedef struct {
     template_config_fields
